@@ -1,12 +1,13 @@
 # coding=utf-8
 #
-# This file is part of Hypothesis (https://github.com/DRMacIver/hypothesis)
+# This file is part of Hypothesis, which may be found at
+# https://github.com/HypothesisWorks/hypothesis-python
 #
 # Most of this work is copyright (C) 2013-2015 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
-# https://github.com/DRMacIver/hypothesis/blob/master/CONTRIBUTING.rst for a
-# full list of people who may hold copyright, and consult the git log if you
-# need to determine who owns an individual contribution.
+# CONTRIBUTING.rst for a full list of people who may hold copyright, and
+# consult the git log if you need to determine who owns an individual
+# contribution.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
@@ -29,9 +30,8 @@ def one_of_strategies(xs):
     xs = tuple(xs)
     if not xs:
         raise ValueError('Cannot join an empty list of strategies')
-    if len(xs) == 1:
-        return xs[0]
-    return OneOfStrategy(xs)
+    from hypothesis.strategies import one_of
+    return one_of(xs)
 
 
 class SearchStrategy(object):
@@ -90,6 +90,7 @@ class SearchStrategy(object):
     """
 
     supports_find = True
+    is_empty = False
 
     def example(self, random=None):
         """Provide an example of the sort of value that this strategy
@@ -166,6 +167,8 @@ class SearchStrategy(object):
         """
         if not isinstance(other, SearchStrategy):
             raise ValueError('Cannot | a SearchStrategy with %r' % (other,))
+        if other.is_empty:
+            return self
         return one_of_strategies((self, other))
 
     def validate(self):
@@ -240,6 +243,7 @@ class MappedSearchStrategy(SearchStrategy):
         self.mapped_strategy = strategy
         if pack is not None:
             self.pack = pack
+        self.is_empty = strategy.is_empty
 
     def __repr__(self):
         if not hasattr(self, '_cached_repr'):
@@ -275,6 +279,7 @@ class FilteredStrategy(SearchStrategy):
         super(FilteredStrategy, self).__init__()
         self.condition = condition
         self.filtered_strategy = strategy
+        self.is_empty = strategy.is_empty
 
     def __repr__(self):
         if not hasattr(self, '_cached_repr'):
